/**
 * Copyright 2017 Julon Lou <contact@julonlou.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

var allowAdaptationsOptions = { "yes": { "appendLabel": "", "appendId": "" }, "no": { "appendLabel": "-NoDerivatives", "appendId": "-nd" }, "share-alike": { "appendLabel": "-ShareAlike", "appendId": "-sa" } };
var allowCommercialUseOptions = { "yes": { "appendLabel": "", "appendId": "" }, "no": { "appendLabel": "-NonCommercial", "appendId": "-nc" } };
var iconSizeOptions = { "normal": "normal", "compact": "compact" };
var options = {
	allowAdaptationsOptions: allowAdaptationsOptions,
	allowCommercialUseOptions: allowCommercialUseOptions,
	iconSizeOptions: iconSizeOptions
};

var iconUrl = function iconUrl(id, size) {
  return "https://i.creativecommons.org/l/" + id + "/4.0/" + size + ".png";
};

var LicenseService = {
  // allowAdaptations ['yes', 'no', 'share-alike']
  getLicense: function getLicense(allowAdaptations, allowCommercialUse) {
    // Retrieve corresponding options
    var adaptation = options.allowAdaptationsOptions[allowAdaptations];
    var commercialUse = options.allowCommercialUseOptions[allowCommercialUse];

    if (adaptation && commercialUse) {
      // Compute id and name
      var id = "by" + commercialUse.appendId + adaptation.appendId;
      var name = "Attribution" + commercialUse.appendLabel + adaptation.appendLabel;

      // Build License object
      return {
        id: id,
        name: "Creative Commons " + name + " 4.0 International License",
        link: "http://creativecommons.org/licenses/" + id + "/4.0/",
        icon: {
          normal: iconUrl(id, "88x31"),
          compact: iconUrl(id, "80x15")
        }
      };
    } else {
      return null;
    }
  }
};

function unwrapExports (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

// 7.2.1 RequireObjectCoercible(argument)
var _defined = function (it) {
  if (it == undefined) throw TypeError("Can't call method on  " + it);
  return it;
};

var _defined$1 = /*#__PURE__*/Object.freeze({
  default: _defined,
  __moduleExports: _defined
});

var defined = ( _defined$1 && _defined ) || _defined$1;

// 7.1.13 ToObject(argument)

var _toObject = function (it) {
  return Object(defined(it));
};

var _toObject$1 = /*#__PURE__*/Object.freeze({
  default: _toObject,
  __moduleExports: _toObject
});

var hasOwnProperty = {}.hasOwnProperty;
var _has = function (it, key) {
  return hasOwnProperty.call(it, key);
};

var _has$1 = /*#__PURE__*/Object.freeze({
  default: _has,
  __moduleExports: _has
});

var toString = {}.toString;

var _cof = function (it) {
  return toString.call(it).slice(8, -1);
};

var _cof$1 = /*#__PURE__*/Object.freeze({
  default: _cof,
  __moduleExports: _cof
});

var cof = ( _cof$1 && _cof ) || _cof$1;

// fallback for non-array-like ES3 and non-enumerable old V8 strings

// eslint-disable-next-line no-prototype-builtins
var _iobject = Object('z').propertyIsEnumerable(0) ? Object : function (it) {
  return cof(it) == 'String' ? it.split('') : Object(it);
};

var _iobject$1 = /*#__PURE__*/Object.freeze({
  default: _iobject,
  __moduleExports: _iobject
});

var IObject = ( _iobject$1 && _iobject ) || _iobject$1;

// to indexed object, toObject with fallback for non-array-like ES3 strings


var _toIobject = function (it) {
  return IObject(defined(it));
};

var _toIobject$1 = /*#__PURE__*/Object.freeze({
  default: _toIobject,
  __moduleExports: _toIobject
});

// 7.1.4 ToInteger
var ceil = Math.ceil;
var floor = Math.floor;
var _toInteger = function (it) {
  return isNaN(it = +it) ? 0 : (it > 0 ? floor : ceil)(it);
};

var _toInteger$1 = /*#__PURE__*/Object.freeze({
  default: _toInteger,
  __moduleExports: _toInteger
});

var toInteger = ( _toInteger$1 && _toInteger ) || _toInteger$1;

// 7.1.15 ToLength

var min = Math.min;
var _toLength = function (it) {
  return it > 0 ? min(toInteger(it), 0x1fffffffffffff) : 0; // pow(2, 53) - 1 == 9007199254740991
};

var _toLength$1 = /*#__PURE__*/Object.freeze({
  default: _toLength,
  __moduleExports: _toLength
});

var max = Math.max;
var min$1 = Math.min;
var _toAbsoluteIndex = function (index, length) {
  index = toInteger(index);
  return index < 0 ? max(index + length, 0) : min$1(index, length);
};

var _toAbsoluteIndex$1 = /*#__PURE__*/Object.freeze({
  default: _toAbsoluteIndex,
  __moduleExports: _toAbsoluteIndex
});

var toIObject = ( _toIobject$1 && _toIobject ) || _toIobject$1;

var toLength = ( _toLength$1 && _toLength ) || _toLength$1;

var toAbsoluteIndex = ( _toAbsoluteIndex$1 && _toAbsoluteIndex ) || _toAbsoluteIndex$1;

// false -> Array#indexOf
// true  -> Array#includes



var _arrayIncludes = function (IS_INCLUDES) {
  return function ($this, el, fromIndex) {
    var O = toIObject($this);
    var length = toLength(O.length);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    // Array#includes uses SameValueZero equality algorithm
    // eslint-disable-next-line no-self-compare
    if (IS_INCLUDES && el != el) while (length > index) {
      value = O[index++];
      // eslint-disable-next-line no-self-compare
      if (value != value) return true;
    // Array#indexOf ignores holes, Array#includes - not
    } else for (;length > index; index++) if (IS_INCLUDES || index in O) {
      if (O[index] === el) return IS_INCLUDES || index || 0;
    } return !IS_INCLUDES && -1;
  };
};

var _arrayIncludes$1 = /*#__PURE__*/Object.freeze({
  default: _arrayIncludes,
  __moduleExports: _arrayIncludes
});

var _global = createCommonjsModule(function (module) {
// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
var global = module.exports = typeof window != 'undefined' && window.Math == Math
  ? window : typeof self != 'undefined' && self.Math == Math ? self
  // eslint-disable-next-line no-new-func
  : Function('return this')();
if (typeof __g == 'number') __g = global; // eslint-disable-line no-undef
});

var _global$1 = /*#__PURE__*/Object.freeze({
  default: _global,
  __moduleExports: _global
});

var require$$0 = ( _global$1 && _global ) || _global$1;

var SHARED = '__core-js_shared__';
var store = require$$0[SHARED] || (require$$0[SHARED] = {});
var _shared = function (key) {
  return store[key] || (store[key] = {});
};

var _shared$1 = /*#__PURE__*/Object.freeze({
  default: _shared,
  __moduleExports: _shared
});

var id = 0;
var px = Math.random();
var _uid = function (key) {
  return 'Symbol('.concat(key === undefined ? '' : key, ')_', (++id + px).toString(36));
};

var _uid$1 = /*#__PURE__*/Object.freeze({
  default: _uid,
  __moduleExports: _uid
});

var require$$0$1 = ( _shared$1 && _shared ) || _shared$1;

var uid = ( _uid$1 && _uid ) || _uid$1;

var shared = require$$0$1('keys');

var _sharedKey = function (key) {
  return shared[key] || (shared[key] = uid(key));
};

var _sharedKey$1 = /*#__PURE__*/Object.freeze({
  default: _sharedKey,
  __moduleExports: _sharedKey
});

var has = ( _has$1 && _has ) || _has$1;

var require$$0$2 = ( _arrayIncludes$1 && _arrayIncludes ) || _arrayIncludes$1;

var require$$1 = ( _sharedKey$1 && _sharedKey ) || _sharedKey$1;

var arrayIndexOf = require$$0$2(false);
var IE_PROTO = require$$1('IE_PROTO');

var _objectKeysInternal = function (object, names) {
  var O = toIObject(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O) if (key != IE_PROTO) has(O, key) && result.push(key);
  // Don't enum bug & hidden keys
  while (names.length > i) if (has(O, key = names[i++])) {
    ~arrayIndexOf(result, key) || result.push(key);
  }
  return result;
};

var _objectKeysInternal$1 = /*#__PURE__*/Object.freeze({
  default: _objectKeysInternal,
  __moduleExports: _objectKeysInternal
});

// IE 8- don't enum bug keys
var _enumBugKeys = (
  'constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf'
).split(',');

var _enumBugKeys$1 = /*#__PURE__*/Object.freeze({
  default: _enumBugKeys,
  __moduleExports: _enumBugKeys
});

var $keys = ( _objectKeysInternal$1 && _objectKeysInternal ) || _objectKeysInternal$1;

var enumBugKeys = ( _enumBugKeys$1 && _enumBugKeys ) || _enumBugKeys$1;

// 19.1.2.14 / 15.2.3.14 Object.keys(O)



var _objectKeys = Object.keys || function keys(O) {
  return $keys(O, enumBugKeys);
};

var _objectKeys$1 = /*#__PURE__*/Object.freeze({
  default: _objectKeys,
  __moduleExports: _objectKeys
});

var _core = createCommonjsModule(function (module) {
var core = module.exports = { version: '2.5.3' };
if (typeof __e == 'number') __e = core; // eslint-disable-line no-undef
});
var _core_1 = _core.version;

var _core$1 = /*#__PURE__*/Object.freeze({
  default: _core,
  __moduleExports: _core,
  version: _core_1
});

var _aFunction = function (it) {
  if (typeof it != 'function') throw TypeError(it + ' is not a function!');
  return it;
};

var _aFunction$1 = /*#__PURE__*/Object.freeze({
  default: _aFunction,
  __moduleExports: _aFunction
});

var aFunction = ( _aFunction$1 && _aFunction ) || _aFunction$1;

// optional / simple context binding

var _ctx = function (fn, that, length) {
  aFunction(fn);
  if (that === undefined) return fn;
  switch (length) {
    case 1: return function (a) {
      return fn.call(that, a);
    };
    case 2: return function (a, b) {
      return fn.call(that, a, b);
    };
    case 3: return function (a, b, c) {
      return fn.call(that, a, b, c);
    };
  }
  return function (/* ...args */) {
    return fn.apply(that, arguments);
  };
};

var _ctx$1 = /*#__PURE__*/Object.freeze({
  default: _ctx,
  __moduleExports: _ctx
});

var _isObject = function (it) {
  return typeof it === 'object' ? it !== null : typeof it === 'function';
};

var _isObject$1 = /*#__PURE__*/Object.freeze({
  default: _isObject,
  __moduleExports: _isObject
});

var isObject = ( _isObject$1 && _isObject ) || _isObject$1;

var _anObject = function (it) {
  if (!isObject(it)) throw TypeError(it + ' is not an object!');
  return it;
};

var _anObject$1 = /*#__PURE__*/Object.freeze({
  default: _anObject,
  __moduleExports: _anObject
});

var _fails = function (exec) {
  try {
    return !!exec();
  } catch (e) {
    return true;
  }
};

var _fails$1 = /*#__PURE__*/Object.freeze({
  default: _fails,
  __moduleExports: _fails
});

var require$$1$1 = ( _fails$1 && _fails ) || _fails$1;

// Thank's IE8 for his funny defineProperty
var _descriptors = !require$$1$1(function () {
  return Object.defineProperty({}, 'a', { get: function () { return 7; } }).a != 7;
});

var _descriptors$1 = /*#__PURE__*/Object.freeze({
  default: _descriptors,
  __moduleExports: _descriptors
});

var document$1 = require$$0.document;
// typeof document.createElement is 'object' in old IE
var is = isObject(document$1) && isObject(document$1.createElement);
var _domCreate = function (it) {
  return is ? document$1.createElement(it) : {};
};

var _domCreate$1 = /*#__PURE__*/Object.freeze({
  default: _domCreate,
  __moduleExports: _domCreate
});

var require$$0$3 = ( _descriptors$1 && _descriptors ) || _descriptors$1;

var require$$2 = ( _domCreate$1 && _domCreate ) || _domCreate$1;

var _ie8DomDefine = !require$$0$3 && !require$$1$1(function () {
  return Object.defineProperty(require$$2('div'), 'a', { get: function () { return 7; } }).a != 7;
});

var _ie8DomDefine$1 = /*#__PURE__*/Object.freeze({
  default: _ie8DomDefine,
  __moduleExports: _ie8DomDefine
});

// 7.1.1 ToPrimitive(input [, PreferredType])

// instead of the ES6 spec version, we didn't implement @@toPrimitive case
// and the second argument - flag - preferred type is a string
var _toPrimitive = function (it, S) {
  if (!isObject(it)) return it;
  var fn, val;
  if (S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
  if (typeof (fn = it.valueOf) == 'function' && !isObject(val = fn.call(it))) return val;
  if (!S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it))) return val;
  throw TypeError("Can't convert object to primitive value");
};

var _toPrimitive$1 = /*#__PURE__*/Object.freeze({
  default: _toPrimitive,
  __moduleExports: _toPrimitive
});

var anObject = ( _anObject$1 && _anObject ) || _anObject$1;

var IE8_DOM_DEFINE = ( _ie8DomDefine$1 && _ie8DomDefine ) || _ie8DomDefine$1;

var toPrimitive = ( _toPrimitive$1 && _toPrimitive ) || _toPrimitive$1;

var dP = Object.defineProperty;

var f = require$$0$3 ? Object.defineProperty : function defineProperty(O, P, Attributes) {
  anObject(O);
  P = toPrimitive(P, true);
  anObject(Attributes);
  if (IE8_DOM_DEFINE) try {
    return dP(O, P, Attributes);
  } catch (e) { /* empty */ }
  if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported!');
  if ('value' in Attributes) O[P] = Attributes.value;
  return O;
};

var _objectDp = {
	f: f
};

var _objectDp$1 = /*#__PURE__*/Object.freeze({
  default: _objectDp,
  __moduleExports: _objectDp,
  f: f
});

var _propertyDesc = function (bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value: value
  };
};

var _propertyDesc$1 = /*#__PURE__*/Object.freeze({
  default: _propertyDesc,
  __moduleExports: _propertyDesc
});

var dP$1 = ( _objectDp$1 && _objectDp ) || _objectDp$1;

var createDesc = ( _propertyDesc$1 && _propertyDesc ) || _propertyDesc$1;

var _hide = require$$0$3 ? function (object, key, value) {
  return dP$1.f(object, key, createDesc(1, value));
} : function (object, key, value) {
  object[key] = value;
  return object;
};

var _hide$1 = /*#__PURE__*/Object.freeze({
  default: _hide,
  __moduleExports: _hide
});

var core = ( _core$1 && _core ) || _core$1;

var ctx = ( _ctx$1 && _ctx ) || _ctx$1;

var hide = ( _hide$1 && _hide ) || _hide$1;

var PROTOTYPE = 'prototype';

var $export = function (type, name, source) {
  var IS_FORCED = type & $export.F;
  var IS_GLOBAL = type & $export.G;
  var IS_STATIC = type & $export.S;
  var IS_PROTO = type & $export.P;
  var IS_BIND = type & $export.B;
  var IS_WRAP = type & $export.W;
  var exports = IS_GLOBAL ? core : core[name] || (core[name] = {});
  var expProto = exports[PROTOTYPE];
  var target = IS_GLOBAL ? require$$0 : IS_STATIC ? require$$0[name] : (require$$0[name] || {})[PROTOTYPE];
  var key, own, out;
  if (IS_GLOBAL) source = name;
  for (key in source) {
    // contains in native
    own = !IS_FORCED && target && target[key] !== undefined;
    if (own && key in exports) continue;
    // export native or passed
    out = own ? target[key] : source[key];
    // prevent global pollution for namespaces
    exports[key] = IS_GLOBAL && typeof target[key] != 'function' ? source[key]
    // bind timers to global for call from export context
    : IS_BIND && own ? ctx(out, require$$0)
    // wrap global constructors for prevent change them in library
    : IS_WRAP && target[key] == out ? (function (C) {
      var F = function (a, b, c) {
        if (this instanceof C) {
          switch (arguments.length) {
            case 0: return new C();
            case 1: return new C(a);
            case 2: return new C(a, b);
          } return new C(a, b, c);
        } return C.apply(this, arguments);
      };
      F[PROTOTYPE] = C[PROTOTYPE];
      return F;
    // make static versions for prototype methods
    })(out) : IS_PROTO && typeof out == 'function' ? ctx(Function.call, out) : out;
    // export proto methods to core.%CONSTRUCTOR%.methods.%NAME%
    if (IS_PROTO) {
      (exports.virtual || (exports.virtual = {}))[key] = out;
      // export proto methods to core.%CONSTRUCTOR%.prototype.%NAME%
      if (type & $export.R && expProto && !expProto[key]) hide(expProto, key, out);
    }
  }
};
// type bitmap
$export.F = 1;   // forced
$export.G = 2;   // global
$export.S = 4;   // static
$export.P = 8;   // proto
$export.B = 16;  // bind
$export.W = 32;  // wrap
$export.U = 64;  // safe
$export.R = 128; // real proto method for `library`
var _export = $export;

var _export$1 = /*#__PURE__*/Object.freeze({
  default: _export,
  __moduleExports: _export
});

var $export$1 = ( _export$1 && _export ) || _export$1;

// most Object methods by ES6 should accept primitives



var _objectSap = function (KEY, exec) {
  var fn = (core.Object || {})[KEY] || Object[KEY];
  var exp = {};
  exp[KEY] = exec(fn);
  $export$1($export$1.S + $export$1.F * require$$1$1(function () { fn(1); }), 'Object', exp);
};

var _objectSap$1 = /*#__PURE__*/Object.freeze({
  default: _objectSap,
  __moduleExports: _objectSap
});

var toObject = ( _toObject$1 && _toObject ) || _toObject$1;

var $keys$1 = ( _objectKeys$1 && _objectKeys ) || _objectKeys$1;

var require$$0$4 = ( _objectSap$1 && _objectSap ) || _objectSap$1;

// 19.1.2.14 Object.keys(O)



require$$0$4('keys', function () {
  return function keys(it) {
    return $keys$1(toObject(it));
  };
});

var keys = core.Object.keys;

var keys$1 = /*#__PURE__*/Object.freeze({
  default: keys,
  __moduleExports: keys
});

var require$$0$5 = ( keys$1 && keys ) || keys$1;

var keys$2 = createCommonjsModule(function (module) {
module.exports = { "default": require$$0$5, __esModule: true };
});

var _Object$keys = unwrapExports(keys$2);

var OptionValidatorService = {
  getOptionValidator: function getOptionValidator(optionName) {
    return function (value) {
      // retrieve available options
      var optionKeys = _Object$keys(options[optionName]);

      // return true if value exist in the available options
      return optionKeys.indexOf(value) !== -1;
    };
  }
};

var validator = OptionValidatorService.getOptionValidator;

var CreativeCommonsMixin = {
  props: {
    allowAdaptations: {
      type: String,
      required: true,
      validator: validator("allowAdaptationsOptions")
    },
    allowCommercialUse: {
      type: String,
      required: true,
      validator: validator("allowCommercialUseOptions")
    }
  },
  computed: {
    license: function license() {
      return LicenseService.getLicense(this.allowAdaptations, this.allowCommercialUse);
    }
  }
};

(function () {
  if (typeof document !== 'undefined') {
    var head = document.head || document.getElementsByTagName('head')[0],
        style = document.createElement('style'),
        css = ".creative-commons-icon--link[data-v-ca185b5c] { display: inline-block; } .creative-commons-icon--img[data-v-ca185b5c] { border: none; } ";style.type = 'text/css';if (style.styleSheet) {
      style.styleSheet.cssText = css;
    } else {
      style.appendChild(document.createTextNode(css));
    }head.appendChild(style);
  }
})();

var validator$1 = OptionValidatorService.getOptionValidator;

var CreativeCommonsIcon = { render: function render() {
    var _vm = this;var _h = _vm.$createElement;var _c = _vm._self._c || _h;return _c('div', { staticClass: "creative-commons-icon" }, [_vm.license ? _c('a', { staticClass: "creative-commons-icon--link", attrs: { "rel": "license", "href": _vm.license.link, "target": "_blank" } }, [_c('img', { staticClass: "creative-commons-icon--img", attrs: { "alt": _vm.license.name, "src": _vm.icon } })]) : _vm._e()]);
  }, staticRenderFns: [], _scopeId: 'data-v-ca185b5c',
  name: "CreativeCommonsIcon",
  mixins: [CreativeCommonsMixin],
  props: {
    iconSize: {
      type: String,
      required: true,
      validator: validator$1("iconSizeOptions")
    }
  },
  computed: {
    icon: function icon() {
      return this.license.icon[this.iconSize];
    }
  }
};

(function () {
  if (typeof document !== 'undefined') {
    var head = document.head || document.getElementsByTagName('head')[0],
        style = document.createElement('style'),
        css = "";style.type = 'text/css';if (style.styleSheet) {
      style.styleSheet.cssText = css;
    } else {
      style.appendChild(document.createTextNode(css));
    }head.appendChild(style);
  }
})();

var CreativeCommonsLabel = { render: function render() {
    var _vm = this;var _h = _vm.$createElement;var _c = _vm._self._c || _h;return _c('div', { staticClass: "creative-commons-label" }, [_c('span', { staticClass: "creative-commons-label--prefix" }, [_vm._v("This work is licensed under a ")]), _c('a', { staticClass: "creative-commons-label--link", attrs: { "rel": "license", "href": _vm.license.link } }, [_vm._v(_vm._s(_vm.license.name))]), _c('span', { staticClass: "creative-commons-label--suffix" }, [_vm._v(".")])]);
  }, staticRenderFns: [],
  name: "CreativeCommonsLabel",
  mixins: [CreativeCommonsMixin]
};

var LibraryModule = {
  CreativeCommonsIcon: CreativeCommonsIcon,
  CreativeCommonsLabel: CreativeCommonsLabel,

  install: function install(Vue) {
    // Register components with vue
    Vue.component("cc-icon", CreativeCommonsIcon);
    Vue.component("cc-label", CreativeCommonsLabel);
  }
};

export default LibraryModule;
export { CreativeCommonsIcon, CreativeCommonsLabel };
